# This rpm spec file is based on packaging approach used by linux-system-roles
# project, as there are no Fedora packaging guidelines for ansible or better
# examples to follow. Target OS is RHEL or CentOS 7.

Name:           tendrl-ansible
Version:        1.5.4
Release:        7%{?dist}
Summary:        Ansible roles and playbooks for Tendrl

License:        LGPLv2.1
Url:            https://github.com/Tendrl/tendrl-ansible
Source0:        %{name}-%{version}.tar.gz
Patch0: 0001-example-of-upstream-changes-in-site.yml.sample.patch
Patch1: 0002-enable-selinux-and-firewall.patch
Patch2: 0003-minimum-required-memory-and-vcpus-for-tendrl-server.patch
Patch3: 0004-default-selinux-mode-enforcing-in-README-files.patch
BuildArch:      noarch

Requires:       ansible >= 2.3
Requires:       python-dns
BuildRequires:  yamllint

# All ansible roles from tendrl-ansible will have this prefix added into the
# name of the role (name of the directory with the role) to prevent conflicts.
%global roleprefix %{name}.

%description
Ansible roles and playbooks for installation of Tendrl, based on upstream
Tendrl documentation.


%prep
%setup -q

# https://bugzilla.redhat.com/show_bug.cgi?id=1502970
# Remove example of suggested changes for adding repo
# releated to other distribution
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# reference roles by prefixed name in sample playbook file
sed -i 's/- \(tendrl-server\)/- %{roleprefix}\1/g' site.yml.sample
sed -i 's/- \(tendrl-storage-node\)/- %{roleprefix}\1/g' site.yml.sample

# reference playbooks by full paths in sample playbook file
sed -i 's!prechecks.yml!%{_pkgdocdir}/&!g'                   site.yml.sample

%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/ansible/roles

# install ansible roles
cp -pR roles/tendrl-server          $RPM_BUILD_ROOT%{_datadir}/ansible/roles/%{roleprefix}tendrl-server
cp -pR roles/tendrl-storage-node    $RPM_BUILD_ROOT%{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node

mkdir -p $RPM_BUILD_ROOT%{_pkgdocdir}/

# install playbooks
install -p -m 644 site.yml.sample                    $RPM_BUILD_ROOT%{_pkgdocdir}/site.yml.sample
install -p -m 644 prechecks.yml                      $RPM_BUILD_ROOT%{_pkgdocdir}/prechecks.yml

# install readme and license files
install -p -m 644 README.rpm.md                $RPM_BUILD_ROOT%{_pkgdocdir}/README.md
install -p -m 644 LICENSE                      $RPM_BUILD_ROOT%{_pkgdocdir}/LICENSE

%check
yamlint $RPM_BUILD_ROOT && rm .yamlint

%files
%{_datadir}/ansible/roles/%{roleprefix}tendrl-server
%{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node

# mark readme files in ansible roles as documentation
%doc %{_datadir}/ansible/roles/%{roleprefix}tendrl-server/README.md
%doc %{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node/README.md

# mark example site.yml file as documentation
%doc %{_pkgdocdir}/site.yml.sample

# playbooks (referenced in site.yml.sample) in doc dir (temporary HACK)
%doc %{_pkgdocdir}/prechecks.yml

# readme and license files
%doc %{_pkgdocdir}/README.md
%license %{_pkgdocdir}/LICENSE

%changelog
* Tue Dec 12 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-7
  Release tendrl-ansible 1.5.4-7

* Fri Dec 08 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-6
  Release tendrl-ansible 1.5.4-6

* Thu Dec 07 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-5
  Release tendrl-ansible 1.5.4-5

* Tue Dec 05 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-4
  Fix firewall disable issue
  Release tendrl-ansible 1.5.4-4

* Tue Dec 05 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-3
  Release tendrl-ansible 1.5.4-3

* Thu Nov 23 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-2
  Release tendrl-ansible 1.5.4-2

* Fri Nov 03 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-1
  Release tendrl-ansible 1.5.4-1

* Thu Nov 02 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.3-3
  Bugfixes Bz#1502970
  Release tendrl-ansible 1.5.3-3

* Mon Oct 16 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.3-2
  Release tendrl-ansible 1.5.3-2

* Wed Sep 27 2017  Martin Bukatovič <mbukatov@redhat.com> - 1.5.3-1
- First release with tendrl-ansible provided in rpm package.
- Initial specfile based on rhel-system-roles packaging style.

